# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/bullhorn.svg' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> Speak
Have Neon repeat whatever you want

## About
Turn Neon into a parrot.  Speak a phrase and listen to it repeated in Mycroft's selected voice. 

## Examples
* "Say Goodnight, Gracie."
* "Repeat I can say anything you'd like!"

## Credits
[Mycroft AI](https://github.com/MycroftAI)
[NeonDaniel](https://github.com/NeonDaniel)

## Category
**Entertainment**

## Tags
#speak
#say
#repeat
#system
